CollectionUtil class

Constructors

CollectionUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

apply<T>(List<T> coll, ApplyFun<T, dynamic> func) → void
arrayCopy<T>(List<T> src, int srcPos, List<T> dest, int destPos, int length) → void
binarySearch<T>(List<T> a, int fromIndex, int toIndex, T key) int
copyOf<T>(List<T> original, int newLength, T fillValue) List<T>
select<T>(List<T> collection, ApplyFun<T, bool> func) List<T>
transform<T, R>(List<T> coll, ApplyFun<T, R> func) List<R>