ConcaveHull class

Constructors

ConcaveHull(Geometry _inputGeometry)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getHull() Geometry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAlpha(double alpha) → void
setHolesAllowed(bool isHolesAllowed) → void
setMaximumEdgeLength(double edgeLength) → void
setMaximumEdgeLengthRatio(double edgeLengthRatio) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

alphaShape(Geometry geom, double alpha, bool isHolesAllowed) Geometry
concaveHullByLength(Geometry geom, double maxLength) Geometry
concaveHullByLength2(Geometry geom, double maxLength, bool isHolesAllowed) Geometry
concaveHullByLengthRatio(Geometry geom, double lengthRatio) Geometry
concaveHullByLengthRatio2(Geometry geom, double lengthRatio, bool isHolesAllowed) Geometry
uniformGridEdgeLength(Geometry geom) double