ConcaveHullOfPolygons class

Constructors

ConcaveHullOfPolygons(Geometry polygons)

Properties

geomFactory GeometryFactory
latefinal
hashCode int
The hash code for this object.
no setterinherited
isHolesAllowed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getFill() Geometry
getHull() Geometry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHolesAllowed(bool isHolesAllowed) → void
setMaximumEdgeLength(double edgeLength) → void
setMaximumEdgeLengthRatio(double edgeLengthRatio) → void
setTight(bool isTight) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

concaveFillByLength(Geometry polygons, double maxLength) Geometry
concaveFillByLengthRatio(Geometry polygons, double lengthRatio) Geometry
concaveHullByLength(Geometry polygons, double maxLength) Geometry
concaveHullByLength2(Geometry polygons, double maxLength, bool isTight, bool isHolesAllowed) Geometry
concaveHullByLengthRatio(Geometry polygons, double lengthRatio) Geometry
concaveHullByLengthRatio2(Geometry polygons, double lengthRatio, bool isTight, bool isHolesAllowed) Geometry