CoordinateArrays class

Constructors

CoordinateArrays()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

atLeastNCoordinatesOrNothing(int n, List<Coordinate> c) List<Coordinate>
compare(List<Coordinate> pts1, List<Coordinate> pts2) int
copyDeep(List<Coordinate> coordinates) List<Coordinate>
copyDeep2(List<Coordinate> src, int srcStart, List<Coordinate> dest, int destStart, int length) → void
dimension(List<Coordinate>? pts) int
enforceConsistency(List<Coordinate?>? array) → void
enforceConsistency2(List<Coordinate?> array, int dimension, int measures) List<Coordinate?>
envelope(List<Coordinate> coordinates) Envelope
equals(List<Coordinate>? coord1, List<Coordinate>? coord2, [CComparator<Coordinate>? c]) bool
extract(List<Coordinate> pts, int start, int end) List<Coordinate>
hasRepeatedOrInvalidPoints(List<Coordinate> coord) bool
hasRepeatedPoints(List<Coordinate> coord) bool
increasingDirection(List<Coordinate> pts) int
indexOf(Coordinate coordinate, List<Coordinate> coordinates) int
intersection(List<Coordinate> coordinates, Envelope env) List<Coordinate>
isEqualReversed(List<Coordinate> pts1, List<Coordinate> pts2) bool
isRing(List<Coordinate> pts) bool
measures(List<Coordinate>? pts) int
minCoordinate(List<Coordinate> coordinates) Coordinate?
ptNotInList(List<Coordinate> testPts, List<Coordinate> pts) Coordinate?
removeNull(List<Coordinate?> coord) List<Coordinate>
removeRepeatedOrInvalidPoints(List<Coordinate> coord) List<Coordinate>
removeRepeatedPoints(List<Coordinate> coord) List<Coordinate>
reverse(List<Coordinate> coord) → void
scroll(List<Coordinate> coordinates, int indexOfFirstCoordinate, [bool? ensureRing]) → void
scroll2(List<Coordinate> coordinates, Coordinate firstCoordinate) → void