DimensionLocation class

Constructors

DimensionLocation()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

dimension(int dimLoc) int
dimension2(int dimLoc, int exteriorDim) int
location(int dimLoc) int
locationArea(int loc) int
locationLine(int loc) int
locationPoint(int loc) int

Constants

kAreaBoundary → const int
kAreaInterior → const int
kExterior → const int
kLineBoundary → const int
kLineInterior → const int
kPointInterior → const int