DirectedEdge class

Inheritance

Constructors

DirectedEdge(Edge edge, bool isForward)

Properties

edge Edge
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isForward bool
getter/setter pair
label Label?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareDirection(EdgeEnd e) int
inherited
compareTo(EdgeEnd e) int
Compares this object to another object.
inherited
computeDirectedLabel() → void
computeLabel(BoundaryNodeRule boundaryNodeRule) → void
inherited
getCoordinate() Coordinate
inherited
getDepth(int position) int
getDepthDelta() int
getDirectedCoordinate() Coordinate
inherited
getDx() double
inherited
getDy() double
inherited
getEdge() Edge
override
getEdgeRing() EdgeRing?
getLabel() Label?
inherited
getMinEdgeRing() EdgeRing?
getNext() DirectedEdge?
getNextMin() DirectedEdge
getNode() Node
inherited
getQuadrant() int
inherited
getSym() DirectedEdge
init(Coordinate p0, Coordinate p1) → void
inherited
isInResult() bool
isInteriorAreaEdge() bool
isLineEdge() bool
isVisited() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setDepth(int position, int depthVal) → void
setEdgeDepths(int position, int depth) → void
setEdgeRing(EdgeRing edgeRing) → void
setInResult(bool isInResult) → void
setMinEdgeRing(EdgeRing minEdgeRing) → void
setNext(DirectedEdge? next) → void
setNextMin(DirectedEdge nextMin) → void
setNode(Node node) → void
inherited
setSym(DirectedEdge de) → void
setVisited(bool isVisited) → void
setVisitedEdge(bool isVisited) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

depthFactor(int currLocation, int nextLocation) int