EdgeSetIntersector class abstract

Implementers

Constructors

EdgeSetIntersector()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeIntersections(List<Edge> edges, SegmentIntersector si, bool testAllSegments) → void
computeIntersections2(List<Edge> edges0, List<Edge> edges1, SegmentIntersector si) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited