GeomComponentFilter2 class

Implemented types

Constructors

GeomComponentFilter2(void apply(Geometry geom))

Properties

apply → void Function(Geometry geom)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

filter(Geometry geom) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited