InteriorIntersectionFinderAdder class
- Inheritance
-
- Object
- NSegmentIntersector
- InteriorIntersectionFinderAdder
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- li ↔ LineIntersector
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getInteriorIntersections(
) → List< Coordinate> -
isDone(
) → bool -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processIntersections(
covariant NodedSegmentString e0, int segIndex0, covariant NodedSegmentString e1, int segIndex1) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited