IntersectionAdder class

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
hasIntersection bool
getter/setter pair
hasProper bool
getter/setter pair
hasProperInterior bool
getter/setter pair
isSelfIntersection bool
getter/setter pair
li LineIntersector
getter/setter pair
numInteriorIntersections int
getter/setter pair
numIntersections int
getter/setter pair
numProperIntersections int
getter/setter pair
numTests int
getter/setter pair
properIntersectionPoint Coordinate?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLineIntersector() LineIntersector
hasInteriorIntersection() bool
hasProperInteriorIntersection() bool
hasProperIntersection() bool
isDone() bool
override
isTrivialIntersection(SegmentString e0, int segIndex0, SegmentString e1, int segIndex1) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processIntersections(covariant NodedSegmentString e0, int segIndex0, covariant NodedSegmentString e1, int segIndex1) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isAdjacentSegments(int i1, int i2) bool