IntersectionPointBuilder class

Constructors

IntersectionPointBuilder(OverlayGraph _graph, GeometryFactory geometryFactory)

Properties

geometryFactory GeometryFactory
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addResultPoints() → void
getPoints() List<Point>
isEdgeOf(OverlayLabel label, int i) bool
isResultPoint(OverlayEdge nodeEdge) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setStrictMode(bool isStrictMode) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited