IsSimpleOpO class

Constructors

IsSimpleOpO([Geometry? inputGeom, BoundaryNodeRule? boundaryNodeRule])

Properties

hashCode int
The hash code for this object.
no setterinherited
inputGeom Geometry?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEndpoint(Map<Coordinate, EndpointInfo> endPoints, Coordinate p, bool isClosed) → void
computeSimple(Geometry geom) bool
getNonSimpleLocation() Coordinate?
hasClosedEndpointIntersection(GeometryGraph graph) bool
hasNonEndpointIntersection(GeometryGraph graph) bool
isSimple() bool
isSimple2(LineString geom) bool
isSimple3(MultiPoint mp) bool
isSimple4(MultiLineString geom) bool
isSimpleGeometryCollection(Geometry geom) bool
isSimpleLinearGeometry(Geometry geom) bool
isSimpleMultiPoint(MultiPoint mp) bool
isSimplePolygonal(Geometry geom) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited