LineBuilder class
Constructors
- LineBuilder(OverlayOp _op, GeometryFactory geometryFactory, PointLocator _ptLocator)
Properties
- geometryFactory ↔ GeometryFactory
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
OverlayOpCode opCode) → List< LineString> -
buildLines(
OverlayOpCode opCode) → void -
collectBoundaryTouchEdge(
DirectedEdge de, OverlayOpCode opCode, List edges) → void -
collectLineEdge(
DirectedEdge de, OverlayOpCode opCode, List edges) → void -
collectLines(
OverlayOpCode opCode) → void -
findCoveredLineEdges(
) → void -
labelIsolatedLine(
Edge e, int targetIndex) → void -
labelIsolatedLines(
List< Edge> edgesList) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited