MathUtil class

Constructors

MathUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

kPhiInv double
final

Static Methods

average(double x1, double x2) double
ceil(int num, int denom) int
clamp(int x, int min, int max) int
clamp2(double x, double min, double max) double
clampMax(int x, int max) int
hypot(double x, double y) double
log10(double x) double
max(double v1, double v2, double v3) double
max2(double v1, double v2, double v3, double v4) double
min(double v1, double v2, double v3, double v4) double
quasirandom(double curr) double
quasirandom2(double curr, double alpha) double
shuffle(int n) List<int>
wrap(int index, int max) int