Matrix class

Constructors

Matrix()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

solve(List<List<double>> a, List<double> b) List<double>?
swapRows(List<double> m, int i, int j) → void
swapRows2(List<List<double>> m, int i, int j) → void