MaximumInscribedCircle class

Constructors

MaximumInscribedCircle(Geometry _inputGeom, double tolerance)

Properties

factory GeometryFactory
latefinal
hashCode int
The hash code for this object.
no setterinherited
radiusPt Coordinate
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tolerance double
getter/setter pair

Methods

getCenter() Point
getRadiusLine() LineString
getRadiusPoint() Point
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

computeMaximumIterations(Geometry geom, double toleranceDist) int
getCenterS(Geometry polygonal, double tolerance) Point
getRadiusLineS(Geometry polygonal, double tolerance) LineString