Orientation class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

index(Coordinate p1, Coordinate p2, Coordinate q) int
isCCW(List<Coordinate> ring) bool
isCCW2(CoordinateSequence ring) bool
isCCWArea(List<Coordinate> ring) bool

Constants

clockwise → const int
collinear → const int
counterClockwise → const int
left → const int
straight → const int