PGEdge class

Inheritance
Implementers

Constructors

PGEdge()
PGEdge.of(DirectedEdgePG de0, DirectedEdgePG de1)

Properties

data Object?
getter/setter pairinherited
dirEdge List<DirectedEdgePG>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isMarked bool
getter/setter pairinherited
isVisited bool
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getContext() Object?
inherited
getDirEdge(int i) DirectedEdgePG
getDirEdge2(PGNode fromNode) DirectedEdgePG?
getOppositeNode(PGNode node) PGNode?
isRemoved() bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → void
setContext(Object? data) → void
inherited
setDirectedEdges(DirectedEdgePG de0, DirectedEdgePG de1) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited