PlanarPolygon3D class

Constructors

PlanarPolygon3D(Polygon poly)

Properties

hashCode int
The hash code for this object.
no setterinherited
poly Polygon
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

averageNormal(CoordinateSequence seq) Vector3D
averagePoint(CoordinateSequence seq) Coordinate
findBestFitPlane(Polygon poly) Plane3D
getPlane() Plane3D
getPolygon() Polygon
intersects(Coordinate intPt) bool
intersects2(Coordinate pt, LineString ring) bool
locate(Coordinate pt, LineString ring) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

project(Coordinate p, int facingPlane) Coordinate
project2(CoordinateSequence seq, int facingPlane) CoordinateSequence