PolygonRingSelfNode class

Constructors

PolygonRingSelfNode(Coordinate nodePt, Coordinate _e00, Coordinate _e01, Coordinate _e10, Coordinate e11)

Properties

hashCode int
The hash code for this object.
no setterinherited
nodePt Coordinate
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCoordinate() Coordinate
isExterior(bool isInteriorOnRight) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited