Rectangle class

Constructors

Rectangle()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFromSidePts(Coordinate baseRightPt, Coordinate baseLeftPt, Coordinate oppositePt, Coordinate leftSidePt, Coordinate rightSidePt, GeometryFactory factory) Polygon