RelateNGNode class

Constructors

RelateNGNode(Coordinate nodePt)

Properties

hashCode int
The hash code for this object.
no setterinherited
nodePt Coordinate
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAreaEdge(bool isA, Coordinate? dirPt, bool isForward) RelateEdge?
addEdge(bool isA, Coordinate? dirPt, int dim, bool isForward) RelateEdge?
addEdges(NodeSection ns) → void
addEdges2(List<NodeSection> nss) → void
addLineEdge(bool isA, Coordinate? dirPt) RelateEdge?
finish(bool isAreaInteriorA, bool isAreaInteriorB) → void
finishNode(bool isA, bool isAreaInterior) → void
getCoordinate() Coordinate
getEdges() List<RelateEdge>
hasExteriorEdge(bool isA) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
propagateSideLocations(bool isA, int startIndex) → void
toString() String
A string representation of this object.
inherited
updateEdgesInArea(bool isA, int indexFrom, int indexTo) → void
updateIfAreaNext(bool isA, int index) → void
updateIfAreaPrev(bool isA, int index) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

nextIndex(List<RelateEdge> list, int i) int
prevIndex(List<RelateEdge> list, int index) int