RobustDeterminant class

Constructors

RobustDeterminant()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

orientationIndex(Coordinate p1, Coordinate p2, Coordinate q) int
signOfDet2x2(double x1, double y1, double x2, double y2) int