RobustLineIntersector class

Inheritance

Constructors

RobustLineIntersector()

Properties

hashCode int
The hash code for this object.
no setterinherited
inputLines List<List<Coordinate>>
2 矩阵 TODO 这里实际上应该为可空
getter/setter pairinherited
intLineIndex List<List<int>>?
getter/setter pairinherited
intPt List<Coordinate>
size always 2
latefinalinherited
isProper bool
getter/setter pairinherited
pa Coordinate
getter/setter pairinherited
pb Coordinate
getter/setter pairinherited
precisionModel PrecisionModel?
getter/setter pairinherited
result int
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeIntersect(Coordinate p1, Coordinate p2, Coordinate q1, Coordinate q2) int
override
computeIntersection(Coordinate p, Coordinate p1, Coordinate p2) → void
override
computeIntersection2(Coordinate p1, Coordinate p2, Coordinate p3, Coordinate p4) → void
inherited
computeIntLineIndex() → void
inherited
computeIntLineIndex2(int segmentIndex) → void
inherited
getEdgeDistance(int segmentIndex, int intIndex) double
inherited
getEndpoint(int segmentIndex, int ptIndex) Coordinate
inherited
getIndexAlongSegment(int segmentIndex, int intIndex) int
inherited
getIntersection(int intIndex) Coordinate
inherited
getIntersectionAlongSegment(int segmentIndex, int intIndex) Coordinate
inherited
getIntersectionNum() int
inherited
hasIntersection() bool
inherited
isCollinear() bool
inherited
isEndPoint() bool
inherited
isInteriorIntersection() bool
inherited
isInteriorIntersection2(int inputLineIndex) bool
inherited
isIntersection(Coordinate pt) bool
inherited
isProperF() bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setMakePrecise(PrecisionModel precisionModel) → void
inherited
setPrecisionModel(PrecisionModel precisionModel) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited