SIRtree<T> class

Inheritance

Constructors

SIRtree([int nodeCapacity = 10])

Properties

hashCode int
The hash code for this object.
no setterinherited
root AbstractNode<Interval>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

boundablesAtLevel(int level) List<Boundable<Interval>>
inherited
boundablesAtLevel2(int level, AbstractNode<Interval> top, List<Boundable<Interval>> boundables) → void
inherited
build() → void
inherited
createHigherLevels(List<Boundable<Interval>> boundablesOfALevel, int level) AbstractNode<Interval>
inherited
createNode(int level) AbstractNode<Interval>
override
createParentBoundables(List<Boundable<Interval>> childBoundables, int newLevel) List<AbstractNode<Interval>>
inherited
depth() int
inherited
depth2(AbstractNode<Interval> node) int
inherited
eachInternal(Interval searchBounds, AbstractNode node, ItemVisitor<T> visitor) → void
inherited
getComparator() → CComparator<Boundable<Interval>>
override
getIntersectsOp() IntersectsOp<Interval>
override
getItemBoundables() List<Boundable<Interval>>
inherited
getNodeCapacity() int
inherited
getRoot() AbstractNode<Interval>
inherited
insert(Interval bounds, T item) → void
inherited
insert2(double x1, double x2, T item) → void
isEmpty() bool
inherited
itemsTree([AbstractNode? node]) List<T>?
inherited
lastNode(List<AbstractNode<Interval>> nodes) AbstractNode<Interval>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(Interval searchBounds) List<T>
inherited
query2(Interval searchBounds, ItemVisitor<T> visitor) → void
inherited
query3(double x) List<T>
query4(double x1, double x2) List<T>
queryInternal(Interval searchBounds, AbstractNode node, List<T> matches) → void
inherited
remove(Interval searchBounds, T item) bool
inherited
remove2(Interval searchBounds, AbstractNode<Interval> node, T item) bool
inherited
removeItem(AbstractNode<Interval> node, T item) bool
inherited
size() int
inherited
size2(AbstractNode<Interval> node) int
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited