SweepLineSegment class

Constructors

SweepLineSegment(Edge edge, int ptIndex)

Properties

edge Edge
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ptIndex int
getter/setter pair
pts List<Coordinate>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeIntersections(SweepLineSegment ss, SegmentIntersector si) → void
getMaxX() double
getMinX() double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited