TopologyComputer class

Constructors

TopologyComputer(TopologyPredicate _predicate, RelateGeometry geomA, RelateGeometry _geomB)

Properties

geomA RelateGeometry
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAreaVertex(bool isAreaA, int locArea, int locTarget, int dimTarget, Coordinate? pt) → void
addAreaVertexOnArea(bool isAreaA, int locArea, int locTarget, Coordinate? pt) → void
addAreaVertexOnLine(bool isAreaA, int locArea, int locTarget, Coordinate? pt) → void
addAreaVertexOnPoint(bool isAreaA, int locArea, Coordinate? pt) → void
addIntersection(NodeSection a, NodeSection b) → void
addLineEndOnArea(bool isLineA, int locLineEnd, int locArea, Coordinate? pt) → void
addLineEndOnGeometry(bool isLineA, int locLineEnd, int locTarget, int dimTarget, Coordinate? pt) → void
addLineEndOnLine(bool isLineA, int locLineEnd, int locLine, Coordinate? pt) → void
addNodeSections(NodeSection ns0, NodeSection ns1) → void
addPointOnGeometry(bool isPointA, int locTarget, int dimTarget, Coordinate pt) → void
addPointOnPointExterior(bool isGeomA, Coordinate? pt) → void
addPointOnPointInterior(Coordinate pt) → void
evaluateNode(NodeSections nodeSections) → void
evaluateNodeEdges(RelateNGNode node) → void
evaluateNodes() → void
finish() → void
getDimension(bool isA) int
getGeometry(bool isA) RelateGeometry
getNodeSections(Coordinate nodePt) NodeSections
getResult() bool
initExteriorDims() → void
initExteriorEmpty(bool geomNonEmpty) → void
isAreaArea() bool
isExteriorCheckRequired(bool isA) bool
isResultKnown() bool
isSelfNodingRequired() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateAreaAreaCross(NodeSection a, NodeSection b) → void
updateDim(int locA, int locB, int dimension) → void
updateDim2(bool isAB, int loc1, int loc2, int dimension) → void
updateIntersectionAB(NodeSection a, NodeSection b) → void
updateNodeLocation(NodeSection a, NodeSection b) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited