VariableBuffer class

Constructors

VariableBuffer(LineString _line, List<double> _distance)

Properties

geomFactory GeometryFactory
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCap(Coordinate p, double r, Coordinate t1, Coordinate t2, CoordinateList coords) → void
capAngle(int index) double
capAngleIndex(double ang) int
circle(Coordinate center, double radius) Polygon?
getResult() Geometry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reflect(LineSegment seg, Coordinate p0, Coordinate p1, double dist0) LineSegment
segmentBuffer(Coordinate p0, Coordinate p1, double dist0, double dist1) Polygon?
segmentBufferOriented(Coordinate p0, Coordinate p1, double dist0, double dist1) Polygon
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buffer(LineString line, double startDistance, double endDistance) Geometry
buffer2(LineString line, List<double> distance) Geometry
buffer3(LineString line, double startDistance, double midDistance, double endDistance) Geometry
indexAtLength(List<Coordinate> pts, double targetLen) int
interpolate(LineString line, double startValue, double endValue) List<double>
interpolate2(LineString line, double startValue, double midValue, double endValue) List<double>
length(List<Coordinate> pts, int i1, int i2) double
outerTangent(Coordinate c1, double r1, Coordinate c2, double r2) LineSegment?
projectPolar(Coordinate p, double r, double ang) Coordinate
snapTrig(double x) double