Vector3D class

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
getter/setter pair
y double
getter/setter pair

Methods

add(Vector3D v) Vector3D
divide(double d) Vector3D
dot(Vector3D v) double
getX() double
getY() double
getZ() double
length() double
normalize() Vector3D
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subtract(Vector3D v) Vector3D
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override