AbstractPreparedPolygonContains class abstract
- Inheritance
-
- Object
- PreparedPolygonPredicate
- AbstractPreparedPolygonContains
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- prepPoly ↔ PreparedPolygon
-
getter/setter pairinherited
- requireSomePointInInterior ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
eval(
Geometry geom) → bool -
evalPoints(
Geometry geom) → bool -
findAndClassifyIntersections(
Geometry geom) → void -
fullTopologicalPredicate(
Geometry geom) → bool -
isAllTestComponentsInTarget(
Geometry testGeom) → bool -
inherited
-
isAllTestComponentsInTargetInterior(
Geometry testGeom) → bool -
inherited
-
isAllTestPointsInTarget(
Geometry testGeom) → bool -
inherited
-
isAnyTargetComponentInAreaTest(
Geometry testGeom, List< Coordinate> targetRepPts) → bool -
inherited
-
isAnyTestComponentInTarget(
Geometry testGeom) → bool -
inherited
-
isAnyTestPointInTargetInterior(
Geometry testGeom) → bool -
inherited
-
isProperIntersectionImpliesNotContainedSituation(
Geometry testGeom) → bool -
isSingleShell(
Geometry geom) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited