AffineTransformationBuilder class
Constructors
- AffineTransformationBuilder(Coordinate _src0, Coordinate _src1, Coordinate _src2, Coordinate _dest0, Coordinate _dest1, Coordinate _dest2)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- m00 ↔ double
-
getter/setter pair
- m01 ↔ double
-
getter/setter pair
- m02 ↔ double
-
getter/setter pair
- m10 ↔ double
-
getter/setter pair
- m11 ↔ double
-
getter/setter pair
- m12 ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compute(
) → bool -
getTransformation(
) → AffineTransformation? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
solve(
List< double> b) → List<double> ? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited