CGAlgorithmsDD class
final
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
intersection(Coordinate p1, Coordinate p2, Coordinate q1, Coordinate q2)
→ Coordinate?
-
-
orientationIndex(Coordinate p1, Coordinate p2, Coordinate q)
→ int
-
-
orientationIndex2(double p1x, double p1y, double p2x, double p2y, double qx, double qy)
→ int
-
-
signOfDet2x2(DD x1, DD y1, DD x2, DD y2)
→ int
-
-
signOfDet2x22(double dx1, double dy1, double dx2, double dy2)
→ int
-