EdgeConnectedTriangleTraversal class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
init(
List< QuadEdgeTriangle> tris) → void -
init2(
QuadEdgeTriangle tri) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
process(
QuadEdgeTriangle currTri, TraversalVisitor visitor) → void -
toString(
) → String -
A string representation of this object.
inherited
-
visitAll(
TraversalVisitor visitor) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited