ElevationModel class
Constructors
- ElevationModel(Envelope _extent, int numCellX, int numCellY)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
Geometry geom) → void -
add2(
double x, double y, double z) → void -
getCell(
double x, double y, bool isCreateIfMissing) → ElevationCell? -
getZ(
double x, double y) → double -
init(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
populateZ(
Geometry geom) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
Geometry geom1, Geometry? geom2) → ElevationModel