GeometryGraph class
- Inheritance
-
- Object
- PGPlanarGraph
- GeometryGraph
Constructors
- GeometryGraph(int _argIndex, Geometry? _parentGeom, BoundaryNodeRule? _boundaryNodeRule)
- GeometryGraph.of(int argIndex, Geometry parentGeom)
Properties
-
edgeEndList
↔ List<
EdgeEnd> -
getter/setter pairinherited
-
edges
↔ List<
Edge> -
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodes ↔ NodeMap
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
EdgeEnd e) → void -
inherited
-
add2(
Geometry g) → void -
addCollection(
GeometryCollection< Geometry> gc) → void -
addEdge(
Edge e) → void -
addEdges(
List< Edge> edgesToAdd) → void -
inherited
-
addLineString(
LineString line) → void -
addNode(
Coordinate coord) → Node -
inherited
-
addNode2(
Node node) → Node -
inherited
-
addPoint(
Point p) → void -
addPoint2(
Coordinate pt) → void -
addPolygon(
Polygon p) → void -
addPolygonRing(
LinearRing lr, int cwLeft, int cwRight) → void -
addSelfIntersectionNode(
int argIndex, Coordinate coord, int loc) → void -
addSelfIntersectionNodes(
int argIndex) → void -
computeEdgeIntersections(
GeometryGraph g, LineIntersector li, bool includeProper) → SegmentIntersector -
computeSelfNodes(
LineIntersector li, bool computeRingSelfNodes) → SegmentIntersector -
computeSplitEdges(
List< Edge> edgeList) → void -
createEdgeSetIntersector(
) → EdgeSetIntersector -
find(
Coordinate coord) → Node? -
inherited
-
findEdge(
Coordinate p0, Coordinate p1) → Edge? -
inherited
-
findEdge2(
LineString line) → Edge? -
findEdgeEnd(
Edge e) → EdgeEnd? -
inherited
-
findEdgeInSameDirection(
Coordinate p0, Coordinate p1) → Edge? -
inherited
-
getBoundaryNodeRule(
) → BoundaryNodeRule? -
getBoundaryNodes(
) → List< Node> -
getBoundaryPoints(
) → List< Coordinate> -
getEdgeEnds(
) → List< EdgeEnd> -
inherited
-
getEdgeIterator(
) → List< Edge> -
inherited
-
getGeometry(
) → Geometry? -
getInvalidPoint(
) → Coordinate? -
getNodeIterator(
) → Iterable< Node> -
inherited
-
getNodes(
) → Iterable< Node> -
inherited
-
hasTooFewPoints(
) → bool -
insertBoundaryPoint(
int argIndex, Coordinate coord) → void -
insertEdge(
Edge e) → void -
inherited
-
insertPoint(
int argIndex, Coordinate coord, int onLocation) → void -
isBoundaryNode(
int geomIndex, Coordinate coord) → bool -
inherited
-
linkAllDirectedEdges(
) → void -
inherited
-
linkResultDirectedEdges(
) → void -
inherited
-
locate(
Coordinate pt) → int -
matchInSameDirection(
Coordinate p0, Coordinate p1, Coordinate ep0, Coordinate ep1) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
determineBoundary(
BoundaryNodeRule boundaryNodeRule, int boundaryCount) → int