HalfEdge class
- Implementers
Constructors
- HalfEdge(Coordinate _orig)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compareAngularDirection(
HalfEdge e) → int -
compareTo(
Object obj) → int -
degree(
) → int -
dest(
) → Coordinate -
directionPt(
) → Coordinate -
directionX(
) → double -
directionY(
) → double -
equals(
Coordinate p0, Coordinate p1) → bool -
find(
Coordinate dest) → HalfEdge? -
insert(
HalfEdge eAdd) → void -
isEdgesSorted(
) → bool -
link(
HalfEdge sym) → void -
next(
) → HalfEdge? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
oNext(
) → HalfEdge? -
orig(
) → Coordinate -
prev(
) → HalfEdge -
prevNode(
) → HalfEdge? -
sym(
) → HalfEdge -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
Coordinate p0, Coordinate p1) → HalfEdge