HotPixelIndex class
Constructors
- HotPixelIndex(PrecisionModel _precModel)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleFactor ↔ double
-
getter/setter pair
Methods
-
add(
Coordinate p) → HotPixel -
add2(
List< Coordinate> pts) → void -
addNodes(
List< Coordinate> pts) → void -
find(
Coordinate pixelPt) → HotPixel? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
Coordinate p0, Coordinate p1, KdNodeVisitor visitor) → void -
round(
Coordinate pt) → Coordinate -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited