LineStringExtracter class
- Implemented types
Constructors
-
LineStringExtracter(List<
LineString> comps)
Properties
-
comps
↔ List<
LineString> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
filter(
Geometry geom) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getGeometry(
Geometry geom) → Geometry -
getLines(
Geometry geom) → List< LineString> -
getLines2(
Geometry geom, List< LineString> lines) → List<LineString>