MultiPolygon class
- Inheritance
-
- Object
- Geometry
- BaseGeometry<
GeometryCollection< Polygon> > - GeometryCollection<
Polygon> - MultiPolygon
- Implemented types
Constructors
-
MultiPolygon(List<
Polygon> ? polygons, PrecisionModel pm, int srid) -
MultiPolygon.of(List<
Polygon> ? polygons, GeometryFactory factory)
Properties
- envelope ↔ Envelope?
-
getter/setter pairinherited
- factory → GeometryFactory
-
finalinherited
-
geometries
↔ List<
Polygon> -
getter/setter pairinherited
- geometryType → GeometryType
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- srid ↔ int
-
getter/setter pairinherited
- userData ↔ dynamic
-
getter/setter pairinherited
Methods
-
apply(
CoordinateFilter filter) → void -
inherited
-
apply2(
CoordinateSequenceFilter filter) → void -
inherited
-
apply3(
GeometryFilter filter) → void -
inherited
-
apply4(
GeometryComponentFilter filter) → void -
inherited
-
buffer(
double distance) → Geometry -
inherited
-
buffer2(
double distance, int quadrantSegments) → Geometry -
inherited
-
buffer3(
double distance, int quadrantSegments, int endCapStyle) → Geometry -
inherited
-
clone(
) → GeometryCollection< Polygon> -
inherited
-
compare(
Iterable< Comparable> a, Iterable<Comparable> b) → int -
A Comparator that compares one comparable to another.
inherited
-
compareTo(
Geometry other) → int -
Compares this object to another object.
inherited
-
compareTo2(
Geometry other, CoordinateSequenceComparator comp) → int -
inherited
-
compareToSameClass(
Object o) → int -
inherited
-
compareToSameClass2(
Object o, CoordinateSequenceComparator comp) → int -
inherited
-
computeEnvelopeInternal(
) → Envelope -
inherited
-
contains(
Geometry g) → bool -
inherited
-
convexHull(
) → Geometry -
inherited
-
copy(
) → GeometryCollection< Polygon> -
inherited
-
copyInternal(
) → MultiPolygon -
override
-
coveredBy(
Geometry g) → bool -
inherited
-
covers(
Geometry g) → bool -
inherited
-
createPointFromInternalCoord(
Coordinate? coord, Geometry exemplar) → Point -
inherited
-
crosses(
Geometry g) → bool -
inherited
-
difference(
Geometry other) → Geometry? -
inherited
-
disjoint(
Geometry g) → bool -
inherited
-
distance(
Geometry g) → double -
inherited
-
equal(
Coordinate a, Coordinate b, double tolerance) → bool -
inherited
-
equals2(
Geometry? g) → bool -
inherited
-
equalsExact(
Geometry other) → bool -
inherited
-
equalsExact2(
Geometry other, double tolerance) → bool -
override
-
equalsNorm(
Geometry? g) → bool -
inherited
-
equalsTopo(
Geometry g) → bool -
inherited
-
geometryChanged(
) → void -
inherited
-
geometryChangedAction(
) → void -
inherited
-
getArea(
) → double -
inherited
-
getBoundary(
) → Geometry -
override
-
getBoundaryDimension(
) → int -
override
-
getCentroid(
) → Point -
inherited
-
getCoordinate(
) → Coordinate? -
inherited
-
getCoordinates(
) → List< Coordinate> -
inherited
-
getDimension(
) → int -
override
-
getEnvelope(
) → Geometry -
inherited
-
getEnvelopeInternal(
) → Envelope -
inherited
-
getGeometryN(
int n) → Polygon -
inherited
-
getInteriorPoint(
) → Point -
inherited
-
getLength(
) → double -
inherited
-
getNumGeometries(
) → int -
inherited
-
getNumPoints(
) → int -
inherited
-
getPrecisionModel(
) → PrecisionModel -
inherited
-
hasDimension(
int dim) → bool -
override
-
intersection(
Geometry other) → Geometry? -
inherited
-
intersects(
Geometry g) → bool -
inherited
-
isEmpty(
) → bool -
inherited
-
isEquivalentClass(
Geometry other) → bool -
inherited
-
isGeometryCollection(
) → bool -
inherited
-
isRectangle(
) → bool -
inherited
-
isSimple(
) → bool -
inherited
-
isValid(
) → bool -
inherited
-
isWithinDistance(
Geometry geom, double distance) → bool -
inherited
-
norm(
) → GeometryCollection< Polygon> -
inherited
-
normalize(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
overlaps(
Geometry g) → bool -
inherited
-
relate(
Geometry g) → IntersectionMatrix -
inherited
-
relate2(
Geometry g, String intersectionPattern) → bool -
inherited
-
reverse(
) → MultiPolygon -
override
-
reverseInternal(
) → MultiPolygon -
override
-
symDifference(
Geometry other) → Geometry? -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
touches(
Geometry g) → bool -
inherited
-
union(
) → Geometry? -
inherited
-
union2(
Geometry other) → Geometry? -
inherited
-
within(
Geometry g) → bool -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited