PGNode class
- Inheritance
-
- Object
- GraphComponentPG
- PGNode
Constructors
- PGNode(Coordinate? pt, [DirectedEdgeStarPG? deStar])
Properties
- data ↔ Object?
-
getter/setter pairinherited
- deStar ↔ DirectedEdgeStarPG
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMarked ↔ bool
-
getter/setter pairinherited
- isVisited ↔ bool
-
getter/setter pairinherited
- pt ↔ Coordinate?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addOutEdge(
DirectedEdgePG de) → void -
getContext(
) → Object? -
inherited
-
getCoordinate(
) → Coordinate? -
getDegree(
) → int -
getIndex(
PGEdge edge) → int -
getOutEdges(
) → DirectedEdgeStarPG -
isRemoved(
) → bool -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
) → void -
remove2(
DirectedEdgePG de) → void -
setContext(
Object? data) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getEdgesBetween(
PGNode node0, PGNode node1) → List< PGEdge>