PolygonHullSimplifier class
Constructors
- PolygonHullSimplifier(Geometry inputGeom, bool _isOuter)
Properties
- geomFactory ↔ GeometryFactory
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputGeom ↔ Geometry
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
computeMultiPolygonAll(
MultiPolygon multiPoly) → Geometry -
computeMultiPolygonEach(
MultiPolygon multiPoly) → Geometry -
computePolygon(
Polygon poly) → Polygon -
createRingHull(
LinearRing ring, bool isOuter, double areaTotal, RingHullIndex? hullIndex) → RingHull -
getResult(
) → Geometry -
initPolygon(
Polygon poly, RingHullIndex? hullIndex) → List< RingHull> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
polygonHull(
Polygon poly, List< RingHull> ringHulls, RingHullIndex? hullIndex) → Polygon -
ringArea(
Polygon poly) → double -
setAreaDeltaRatio(
double areaDeltaRatio) → void -
setVertexNumFraction(
double vertexNumFraction) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited