VertexTaggedGeometryDataMapper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCoordinates(
) → List< Coordinate> -
loadSourceGeometries(
List< Geometry> geoms) → void -
loadSourceGeometries2(
Geometry geomColl) → void -
loadVertices(
List< Coordinate> pts, Object? data) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transferData(
Geometry targetGeom) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited